@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2025, by Samuel Williams.
+# Copyright, 2025-2026, by Samuel Williams.
 
 require_relative "split"
 require_relative "../quoted_string"
@@ -62,16 +62,30 @@ module Protocol
 					end
 				end
 				
-				# Initializes the TE header with the given value. The value is split into distinct entries and converted to lowercase for normalization.
+				# Parses a raw header value.
 				#
-				# @parameter value [String | Nil] the raw header value containing transfer encodings separated by commas.
-				def initialize(value = nil)
-					super(value&.downcase)
+				# @parameter value [String] a raw header value containing comma-separated encodings.
+				# @returns [TE] a new instance with normalized (lowercase) encodings.
+				def self.parse(value)
+					self.new(value.downcase.split(COMMA))
+				end
+				
+				# Coerces a value into a parsed header object.
+				#
+				# @parameter value [String | Array] the value to coerce.
+				# @returns [TE] a parsed header object with normalized values.
+				def self.coerce(value)
+					case value
+					when Array
+						self.new(value.map(&:downcase))
+					else
+						self.parse(value.to_s)
+					end
 				end
 				
 				# Adds one or more comma-separated values to the TE header. The values are converted to lowercase for normalization.
 				#
-				# @parameter value [String] the value or values to add, separated by commas.
+				# @parameter value [String] a raw header value containing one or more values separated by commas.
 				def << value
 					super(value.downcase)
 				end
@@ -91,32 +105,32 @@ module Protocol
 				
 				# @returns [Boolean] whether the `chunked` encoding is accepted.
 				def chunked?
-					self.any? {|value| value.start_with?(CHUNKED)}
+					self.any?{|value| value.start_with?(CHUNKED)}
 				end
 				
 				# @returns [Boolean] whether the `gzip` encoding is accepted.
 				def gzip?
-					self.any? {|value| value.start_with?(GZIP)}
+					self.any?{|value| value.start_with?(GZIP)}
 				end
 				
 				# @returns [Boolean] whether the `deflate` encoding is accepted.
 				def deflate?
-					self.any? {|value| value.start_with?(DEFLATE)}
+					self.any?{|value| value.start_with?(DEFLATE)}
 				end
 				
 				# @returns [Boolean] whether the `compress` encoding is accepted.
 				def compress?
-					self.any? {|value| value.start_with?(COMPRESS)}
+					self.any?{|value| value.start_with?(COMPRESS)}
 				end
 				
 				# @returns [Boolean] whether the `identity` encoding is accepted.
 				def identity?
-					self.any? {|value| value.start_with?(IDENTITY)}
+					self.any?{|value| value.start_with?(IDENTITY)}
 				end
 				
 				# @returns [Boolean] whether trailers are accepted.
 				def trailers?
-					self.any? {|value| value.start_with?(TRAILERS)}
+					self.any?{|value| value.start_with?(TRAILERS)}
 				end
 				
 				# Whether this header is acceptable in HTTP trailers.
@@ -129,3 +143,4 @@ module Protocol
 		end
 	end
 end
+
