@@ -12,16 +12,30 @@ module Protocol
 			#
 			# The `vary` header is used in HTTP responses to indicate which request headers affect the selected response. It allows caches to differentiate stored responses based on specific request headers.
 			class Vary < Split
-				# Initializes a `Vary` header with the given value. The value is split into distinct entries and converted to lowercase for normalization.
+				# Parses a raw header value.
 				#
-				# @parameter value [String] the raw header value containing request header names separated by commas.
-				def initialize(value)
-					super(value.downcase)
+				# @parameter value [String] a raw header value containing comma-separated header names.
+				# @returns [Vary] a new instance with normalized (lowercase) header names.
+				def self.parse(value)
+					self.new(value.downcase.split(COMMA))
+				end
+				
+				# Coerces a value into a parsed header object.
+				#
+				# @parameter value [String | Array] the value to coerce.
+				# @returns [Vary] a parsed header object with normalized values.
+				def self.coerce(value)
+					case value
+					when Array
+						self.new(value.map(&:downcase))
+					else
+						self.parse(value.to_s)
+					end
 				end
 				
 				# Adds one or more comma-separated values to the `vary` header. The values are converted to lowercase for normalization.
 				#
-				# @parameter value [String] the value or values to add, separated by commas.
+				# @parameter value [String] a raw header value containing one or more values separated by commas.
 				def << value
 					super(value.downcase)
 				end
@@ -29,3 +43,4 @@ module Protocol
 		end
 	end
 end
+
